@@ -15,6 +15,7 @@
  */
 
 #include "var_export_xml.h"
+#include "xdebug_strndup.h"
 #include "Zend/zend_closures.h"
 
 static xdebug_str *prepare_variable_name(xdebug_str *name)
@@ -612,10 +613,10 @@ void xdebug_var_export_xml_node(zval **struc, xdebug_str *name, xdebug_xml_node
 
 #if PHP_VERSION_ID >= 80400
 			if (ce->type != ZEND_INTERNAL_CLASS && zend_object_is_lazy(Z_OBJ_P(*struc))) {
-				xdebug_xml_add_attribute(node, "type", "object");
 				if (zend_object_is_lazy_proxy(Z_OBJ_P(*struc))) {
 					xdebug_xml_expand_attribute_value(node, "facet", "lazy-proxy");
 				} else if (!zend_lazy_object_initialized(Z_OBJ_P(*struc))) {
+					xdebug_xml_add_attribute(node, "type", "object");
 					xdebug_xml_expand_attribute_value(node, "facet", "lazy-ghost");
 
 					break; /* Jump out of the function */
@@ -837,8 +838,8 @@ xdebug_xml_node* xdebug_get_zval_value_xml_node_ex(xdebug_str *name, zval *val,
 				xdebug_str_add_literal(&tmp_formatted_name, "::");
 				xdebug_str_add_str(&tmp_formatted_name, name);
 
-				short_name = xdebug_str_copy(&tmp_formatted_name);
-				full_name =  xdebug_str_copy(&tmp_formatted_name);
+				short_name = xdebug_str_clone(&tmp_formatted_name);
+				full_name =  xdebug_str_clone(&tmp_formatted_name);
 
 				xdebug_str_destroy(&tmp_formatted_name);
 			} break;
